@@ -388,7 +388,7 @@ signal_is_needed (AtkObject *obj, const gchar *klass, const gchar *major,
   if (!spi_global_app_data->events_initialized)
     return TRUE;
 
-  data [0] = ensure_proper_format (klass + 21);
+  data [0] = ensure_proper_format (klass[0] ? klass + 21 : klass);
   data [1] = ensure_proper_format (major);
   data [2] = ensure_proper_format (minor);
   data [3] = NULL;
@@ -689,11 +689,9 @@ do_debug_thing (AtkObject *accessible)
     parent = atk_object_get_parent (accessible);
     if (!ATK_IS_COMPONENT (accessible))
     {
-      g_print ("%s isn't a component\n", g_type_name_from_instance(accessible));
     return;
   }
     atk_component_get_extents (ATK_COMPONENT (accessible), &x, &y, &width, &height, ATK_XY_SCREEN);
-    g_print ("extents for %s (%s): %d %d %d %d\n", atk_object_get_name(accessible), g_type_name_from_instance(accessible), x, y, width, height);
     accessible = parent;
   } while (accessible);
 }
